# Python-Homework-Open-Source-Project

![Homework-Open-Source.jpg](https://repository-images.githubusercontent.com/531410247/c87eee78-e33b-48c5-938d-33340f8415ce)

### [1] 今后有关"Python程序设计"的所有作业都会在此开源.

### [2] 任何人都能够随意的浏览和下载这里的代码.

### [3] 任何人都可以创建新的分支并提交自己的代码.

### [4] 让我们一起维护好开源生态吧!

### ~~[本人从C++那里来的,接触Python没几天]~~

***
